@@ -11,6 +11,7 @@ from deskbar.ui.cuemiac.CuemiacTreeView import CuemiacTreeView
 from deskbar.ui.cuemiac.CuemiacItems import CuemiacCategory
 from deskbar.ui.cuemiac.CuemiacHistory import CuemiacHistoryView
 from deskbar.ui.cuemiac.CuemiacActionsTreeView import CuemiacActionsTreeView, CuemiacActionsModel
+from deskbar.ui.cuemiac.LingeringSelectionWindow import LingeringSelectionWindow
 
 class CuemiacWindowView(deskbar.interfaces.View, gtk.Window):
     """
@@ -104,6 +105,8 @@ class CuemiacWindowView(deskbar.interfaces.View, gtk.Window):
         self.cview.connect ("row-collapsed", self._controller.on_category_collapsed, self.treeview_model)
         self.cview.show()
         
+        LingeringSelectionWindow (self.cview)
+        
         self.scrolled_results = gtk.ScrolledWindow ()
         self.scrolled_results.set_policy (gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
         self.scrolled_results.set_shadow_type(gtk.SHADOW_IN)
@@ -119,6 +122,8 @@ class CuemiacWindowView(deskbar.interfaces.View, gtk.Window):
         self.aview.connect ("go-back", self.__on_go_back)
         self.aview.show()
         
+        LingeringSelectionWindow (self.aview)
+        
         self.scrolled_actions = gtk.ScrolledWindow()
         self.scrolled_actions.set_policy (gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
         self.scrolled_actions.set_shadow_type(gtk.SHADOW_IN)
@@ -144,7 +149,7 @@ class CuemiacWindowView(deskbar.interfaces.View, gtk.Window):
         self.results_box.pack_start(self.scrolled_results)
         self.results_box.pack_start(self.actions_box)
         self.vbox_main.pack_start(self.results_box)
-    
+   
     def clear_all(self):
         deskbar.interfaces.View.clear_all(self)
         width, height = self.get_size()
@@ -276,4 +281,4 @@ class CuemiacWindowView(deskbar.interfaces.View, gtk.Window):
         """
         Save window height before results_box disappears
         """
-        self._model.set_window_height( self.get_size()[1] )
\ No newline at end of file
+        self._model.set_window_height( self.get_size()[1] )
